/* 
 * (c) Copyright IBM Corp. 2005, 2006. All Rights Reserved. 
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement. 
 */
package importer;

import java.util.Iterator;
import java.util.NoSuchElementException;

import com.ibm.rational.test.mt.importer.interfaces.IMTAImportNode;

/**
 * Iterates over all child nodes of a block
 */
public class ExampleNodeIterator implements Iterator
{
	static final int UNINITIALIZED = -1;
	
	int currentNode = UNINITIALIZED;
	IMTAImportNode nodes[] = {
			ExampleMTAImportNode.createNode(
					IMTAImportNode.TYPE_STEP,
					"Enter name",
					"In the name field enter the value - John Doe",
					null ),
			ExampleMTAImportNode.createNode(
					IMTAImportNode.TYPE_STEP,
					null,
					"Click on the \"Submit\" button",
					null )
	};
	
	/**
	 * Return true if there are more nodes
	 * @return true=more nodes, false=no more nodes
	 */
	public boolean hasNext()
	{
		if (currentNode == UNINITIALIZED)
			return true;
		
		return (currentNode < nodes.length-1);
	}

	/**
	 * Return the next root node of the next document to import
	 * @return root node
	 */
	public Object next()
	{
		if (currentNode == UNINITIALIZED)
		{
			currentNode = 0;
			return nodes[currentNode];
		}
		else if (currentNode < nodes.length-1)
		{
			return nodes[++currentNode];
		}
		
		throw new NoSuchElementException();
	}

	/**
	 * This operation not supported.
	 */
	public void remove()
	{
		throw new UnsupportedOperationException();
	}
}
